@@ -2,7 +2,7 @@ package Config::IniFiles;
 
 use vars qw($VERSION);
 
-$VERSION = "2.49";
+$VERSION = "2.50";
 
 require 5.004;
 use strict;
@@ -1299,11 +1299,13 @@ sub SetFileName {
   return undef;
 }
 
-# OutputConfig
-#
-# Writes OutputConfig to STDOUT. Use select() to redirect STDOUT to
-# the output target before calling this function. Optional argument
-# should be set to 1 if writing only delta.
+=head2 $ini->OutputConfig($delta)
+
+Writes OutputConfig to STDOUT. Use select() to redirect STDOUT to
+the output target before calling this function. Optional argument
+should be set to 1 if writing only delta.
+
+=cut
 
 sub OutputConfig {
     my ($self, $delta) = @_;
@@ -1646,7 +1648,7 @@ sub GetParameterEOT
 	return $self->{EOT}{$sect}{$parm};
 }
 
-=head2 SetParameterEOT ($section, $EOT)
+=head2 $cfg->SetParameterEOT ($section, $parameter, $EOT)
 
 Accessor method for the EOT text for the specified parameter. Sets the HERE style marker text to the value $EOT. Once the EOT text is set, that parameter will be saved in HERE style.
 
@@ -2461,10 +2463,6 @@ modify it under the same terms as Perl itself.
 
 1;
 
-=cut
-
-1;
-
 # Please keep the following within the last four lines of the file
 #[JW for editor]:mode=perl:tabSize=8:indentSize=2:noTabs=true:indentOnEnter=true:
 
